@@ -142,6 +142,41 @@ def GetRAP(UserID):
             Done = True
     return(TotalValue)
 
+def GetLimiteds(UserID):
+    """
+    Returns the total list of a users limiteds
+
+    Please be aware this function can take some time to run depending on internet speed and how many limiteds a user owns
+    """
+    Limiteds = []
+    IDs = []
+    Cursor = ""
+    Done = False
+    while(Done == False):
+        try:
+            response = requests.get(Utils.Inventory1URL + f"/{UserID}/assets/collectibles?sortOrder=Asc&limit=100&cursor={Cursor}")
+            Items = response.json()
+            if((response.json()['nextPageCursor'] == "null") or response.json()['nextPageCursor'] == None):
+                Done = True
+            else:
+                Done = False
+                Cursor = response.json()['nextPageCursor']
+            for Item in Items["data"]:
+                try:
+                    Limited = Item['name']
+                    ID = Item['assetId']
+                    Limiteds.append(Limited)
+                    IDs.append(ID)
+                except:
+                    Limiteds = Limiteds
+                    IDs = IDs
+            if(response.json()['nextPageCursor'] == 'None'):
+                Done = True
+            
+        except Exception as ex:
+            Done = True
+    return(Limiteds,IDs)
+
 def GetBust(UserID,Width = 420, Height = 420):
     """
     Returns the link to a bust image of a user
@@ -169,10 +204,13 @@ def GetStatus(UserID):
 
 def DoesNameExist(Username):
     response = requests.get(Utils.UserAPIV1 + 'get-by-username?username=' + str(Username))
-    if('errorMessage' in response.text):
-        return ('Availible')
-    else:
-        if(response.json()['Username'].lower() == Username.lower()):
-            return('Unavailible')
-        elif (response.json()['Username'].lower() != Username.lower()):
-            return('Availible')
\ No newline at end of file
+    try:
+        if('errorMessage' in response.text):
+            return ('Availible')
+        else:
+            if(response.json()['Username'].lower() == Username.lower()):
+                return('Unavailible')
+            elif (response.json()['Username'].lower() != Username.lower()):
+                return('Availible')
+    except:
+        return response.json()
\ No newline at end of file
